@@ -1,6 +1,7 @@
 import base64
 import importlib
 import logging
+import sys
 from hashlib import sha256
 from importlib.util import module_from_spec, spec_from_loader
 from pathlib import Path
@@ -55,21 +56,44 @@ def fromSource(src: str, filename: str = "<string>", hashcode: str = "") -> Exte
     """
     logger.info("Load extension from source: %s...", src[:20])
 
-    rhashcode = hashed(src)
-    if hashcode and rhashcode != hashcode:
-        raise CoxbuildException("Unmatched hashcode.")
+    if src == "stdin":
+        src = sys.stdin.read()
+    if src == "interactive":
+        if hashcode:
+            raise CoxbuildException(
+                "Cannot specify hashcode for interactive source.")
+        import code
 
-    spec = spec_from_loader(rhashcode, loader=None)
-    mod = module_from_spec(spec)
+        id = str(uuid1())
+        spec = spec_from_loader(id, loader=None)
+        mod = module_from_spec(spec)
+        mod.__dict__["__module__"] = mod
 
-    code = compile(src, filename, "exec")
+        ext = fromModule(mod)
+        ext.uri = f"src://interactive@{id}"
+        mod.__dict__["__extension__"] = ext
 
-    exec("from coxbuild.schema import *", mod.__dict__)
-    exec(code, mod.__dict__)
+        exec("from coxbuild.schema import *", mod.__dict__)
+        exec("manager.register(__extension__)", mod.__dict__)
+        code.interact(banner="Interactive Schema", local=mod.__dict__)
+        exec("manager.unregister(__extension__)", mod.__dict__)
+    else:
+        rhashcode = hashed(src)
+        if hashcode and rhashcode != hashcode:
+            raise CoxbuildException("Unmatched hashcode.")
+
+        spec = spec_from_loader(rhashcode, loader=None)
+        mod = module_from_spec(spec)
+
+        srccode = compile(src, filename, "exec")
+
+        exec("from coxbuild.schema import *", mod.__dict__)
+        exec(srccode, mod.__dict__)
+
+        ext = fromModule(mod)
+        ext.uri = f"src@{rhashcode}://{base64.b64encode(src.encode()).decode()}"
+        ext.hashcode = rhashcode
 
-    ext = fromModule(mod)
-    ext.uri = f"src@{rhashcode}://{base64.b64encode(src.encode()).decode()}"
-    ext.hashcode = rhashcode
     return ext
 
 
@@ -117,67 +141,23 @@ def fromGallery(name: str, version: str = "", hashcode: str = "") -> Extension:
 
     ext@{hashcode}://{name}@{version}
 
-    https://cdn.jsdelivr.net/gh/StardustDL/coxbuild-ext-gallery@{version}/exts/{name}.py
-
     :param name: name of extension
     :param version: version of extension
     :param hashcode: hashcode
     """
     logger.info("Load extension from gallery: %s", name)
 
-    if not version:
-        version = "main"
+    from .gallery import galleries
 
-    ext = fromUrl(
-        f"https://cdn.jsdelivr.net/gh/StardustDL/coxbuild-ext-gallery@{version}/exts/{name}.py", hashcode)
-    ext.uri = f"ext@{ext.hashcode}://{name}@{version}"
-    return ext
+    gals = galleries()
 
+    for gal in gals:
+        ext = gal.load(name, version, hashcode)
+        if ext:
+            return ext
 
-def fromGalleryRaw(name: str, version: str = "", hashcode: str = "") -> Extension:
-    """
-    Load extension from gallery (raw).
-
-    extraw@{hashcode}://{name}@{version}
-
-    https://raw.githubusercontent.com/StardustDL/coxbuild-ext-gallery/{version}/exts/{name}.py
-
-    :param name: name of extension
-    :param version: version of extension
-    :param hashcode: hashcode
-    """
-    logger.info("Load extension from gallery (raw): %s", name)
-
-    if not version:
-        version = "main"
-
-    ext = fromUrl(
-        f"https://raw.githubusercontent.com/StardustDL/coxbuild-ext-gallery/{version}/exts/{name}.py", hashcode)
-    ext.uri = f"extraw@{ext.hashcode}://{name}@{version}"
-    return ext
-
-
-def fromGalleryCn(name: str, version: str = "", hashcode: str = "") -> Extension:
-    """
-    Load extension from gallery (cn).
-
-    extcn@{hashcode}://{name}@{version}
-
-    https://gitee.com/stardustdl/coxbuild-ext-gallery/raw/{version}/exts/{name}.py
-
-    :param name: name of extension
-    :param version: version of extension
-    :param hashcode: hashcode
-    """
-    logger.info("Load extension from gallery (raw): %s", name)
-
-    if not version:
-        version = "main"
-
-    ext = fromUrl(
-        f"https://gitee.com/stardustdl/coxbuild-ext-gallery/raw/{version}/exts/{name}.py", hashcode)
-    ext.uri = f"extcn@{ext.hashcode}://{name}@{version}"
-    return ext
+    raise CoxbuildException(
+        f"Failed to load extension from gallery: {name}@{version}")
 
 
 def load(uri: str):
@@ -199,7 +179,13 @@ def load(uri: str):
         ext = fromModule(importlib.import_module(name), version)
         return ext
     elif schema == "src":
-        src = base64.b64decode(path.encode()).decode()
+        path = path.strip()
+        if path == "stdin":
+            src = path
+        elif path == "interactive":
+            src = path
+        else:
+            src = base64.b64decode(path.encode()).decode()
         ext = fromSource(src, filename="<string>", hashcode=hashcode)
         return ext
     elif schema == "file":
@@ -217,21 +203,5 @@ def load(uri: str):
             name, version = items
         ext = fromGallery(name, version, hashcode)
         return ext
-    elif schema == "extraw":
-        items = path.split("@", 1)
-        if len(items) != 2:
-            name, version = items[0], ""
-        else:
-            name, version = items
-        ext = fromGalleryRaw(name, version, hashcode)
-        return ext
-    elif schema == "extcn":
-        items = path.split("@", 1)
-        if len(items) != 2:
-            name, version = items[0], ""
-        else:
-            name, version = items
-        ext = fromGalleryCn(name, version, hashcode)
-        return ext
     else:
         raise CoxbuildException(f"Unknown extension schema: {schema}")
