@@ -5,7 +5,7 @@ import sys
 import traceback
 from dataclasses import dataclass, field
 from datetime import datetime, timedelta
-from typing import Any, Awaitable, Callable
+from typing import TYPE_CHECKING, Any, Awaitable, Callable
 
 from coxbuild.configuration import Configuration
 from coxbuild.hooks import Hook
@@ -13,6 +13,9 @@ from coxbuild.hooks import Hook
 from .exceptions import CoxbuildException
 from .runners import Runner
 
+if TYPE_CHECKING:
+    from .extensions import Extension
+
 logger = logging.getLogger("tasks")
 
 
@@ -32,8 +35,8 @@ class TaskContext:
 @dataclass
 class TaskResult:
     """Execution result for task."""
-    name: str
-    """task name"""
+    task: "Task"
+    """task"""
     duration: timedelta
     """execution duration"""
     exception: CoxbuildException | None
@@ -164,14 +167,17 @@ class Task:
     """task body"""
     description: str = ""
     """task document"""
-    deps: list[str] = field(default_factory=list)
+    deps: list["Task"] = field(default_factory=list)
     """dependency task names"""
     hooks: list[TaskHook] = field(default_factory=list)
     """task hooks"""
+    continueOnError: bool = False
+    """continue execution on error"""
+    extension: "Extension | None" = None
 
     def copy(self) -> "Task":
         """Clone task."""
-        return Task(self.name, self.body, self.description, self.deps.copy(), self.hooks.copy())
+        return Task(self.name, self.body, self.description, self.deps.copy(), self.hooks.copy(), self.continueOnError, self.extension)
 
     def __call__(self, *args: Any, **kwds: Any) -> "TaskRunner":
         """
@@ -184,9 +190,12 @@ class Task:
         """
         return TaskRunner(self, list(args), kwds)
 
+    def __hash__(self) -> int:
+        return id(self)
+
     def depend(self, task: "Task") -> "Task":
         """Add dependency task."""
-        self.deps.append(task.name)
+        self.deps.append(task)
         return task
 
     def hook(self, hook: TaskHook) -> "TaskHook":
@@ -241,19 +250,31 @@ class TaskRunner(Runner):
 
     async def _before(self):
         logger.debug(f"Run task before hook for {self.context.task.name}")
-        for hook in self.before:
-            pre = hook.hook(self.context)
-            if inspect.isawaitable(pre):
-                pre: bool = await pre
-            if pre == False:
-                return False
+        try:
+            for hook in self.before:
+                pre = hook.hook(self.context)
+                if inspect.isawaitable(pre):
+                    pre: bool = await pre
+                if pre == False:
+                    return False
+        except Exception as ex:
+            logger.error(
+                f"Task before hook failed for {self.context.task.name}", exc_info=ex)
+            print(
+                f"Task before hook failed for {self.context.task.name}: {ex}")
+            return False
 
     async def _after(self):
         logger.debug(f"Run task after hook for {self.context.task.name}")
-        for hook in self.after:
-            res = hook.hook(self.context, self.result)
-            if inspect.isawaitable(res):
-                await res
+        try:
+            for hook in self.after:
+                res = hook.hook(self.context, self.result)
+                if inspect.isawaitable(res):
+                    await res
+        except Exception as ex:
+            logger.error(
+                f"Task after hook failed for {self.context.task.name}", exc_info=ex)
+            print(f"Task after hook failed for {self.context.task.name}: {ex}")
 
     async def _setup(self):
         logger.debug(f"Task {self.context.task.name} setup hook.")
@@ -340,7 +361,7 @@ class TaskRunner(Runner):
         exception = None if self.exc_value is None else CoxbuildException(
             f"Failed to run task: {self.context.task.name}", cause=self.exc_value)
         self.result = TaskResult(
-            self.context.task.name, duration=self.duration, exception=exception)
+            self.context.task, duration=self.duration, exception=exception)
 
         if self.exc_value is not None:
             logger.error("Task execute exception.", exc_info=self.exc_value)
@@ -382,6 +403,14 @@ def named(name: str):
     return decorator
 
 
+def continueOnError(inner: Task) -> Task:
+    """
+    Decorator to continue task execution on error.
+    """
+    inner.continueOnError = True
+    return inner
+
+
 def group(*names: str):
     """
     Decorator to set task group.
@@ -392,15 +421,15 @@ def group(*names: str):
     return decorator
 
 
-def depend(*names: str | Task):
+def depend(*tasks: Task):
     """
     Decorator to define dependencies of a task.
 
     names: task names or task instances
     """
     def decorator(inner: Task) -> Task:
-        for name in names:
-            inner.deps.append(name if isinstance(name, str) else name.name)
+        for task in tasks:
+            inner.depend(task)
         return inner
     return decorator
 
